/** @jsx h */
import { styled } from "../preact";
import { h } from "preact";
function CustomComponent({ title, ...props }) {
    return h("div", { ...props }, title);
}
const Card = styled("div", "bg-white p-4 border-2 rounded-lg");
const TitleCard = styled(CustomComponent, "bg-white p-4 border-2 rounded-lg");
const Button = styled("button", {
    base: "px-5 py-2 text-white disabled:bg-gray-400 disabled:text-gray-300",
    variants: {
        color: {
            neutral: "bg-slate-500 hover:bg-slate-400",
            accent: "bg-teal-500 hover:bg-teal-400",
        },
        size: {
            small: "text-sm",
            medium: "text-md",
        },
        outlined: {
            true: "border-2",
        },
        rounded: {
            true: "rounded-full",
            false: "rounded-sm",
        },
    },
    compoundVariants: [
        {
            variants: { color: "accent", outlined: true },
            className: "border-teal-600",
        },
    ],
    defaultVariants: {
        color: "neutral",
    },
});
export const ExpectErrors = styled("div", {
    variants: {
        color: {
            neutral: "grey",
            accent: "hotpink",
        },
    },
    compoundVariants: [
        {
            //@ts-expect-error
            variants: { outlined: true },
            className: "",
        },
    ],
    defaultVariants: {
        //@ts-expect-error
        outlined: true,
    },
});
export function WithErrors() {
    return (h("div", null,
        h(Button, { foo: true, size: "medium" }, "unknown property"),
        h(Card, { foo: true }, "Unknown property"),
        h(Button, { size: "medium", color: "foo" }, "Invalid variant"),
        h(Button, null, "Missing size")));
}
export function PreactApp() {
    return (h("div", { className: "flex justify-center items-center pt-8 gap-4 flex-wrap" },
        h(Button, { size: "medium", onClick: console.log }, "Accent"),
        h(Button, { size: "medium", rounded: true }, "Neutral + Rounded"),
        h(Button, { size: "medium", color: "accent", outlined: true }, "Accent + Outlined"),
        h(Button, { size: "medium", color: "accent", disabled: true }, "Disabled"),
        h(TitleCard, { title: "Hello" }),
        h(Card, null,
            h("h1", null, "Hello"),
            h("p", null, "world")),
        h(Card, { as: "a", href: "https://example.com" }, "Link"),
        h(Card, { as: CustomComponent, title: "Test" })));
}
