import type { JSX, ComponentType, ComponentProps, VNode } from "preact";
type ElementType<P = any> = keyof JSX.IntrinsicElements | ComponentType<P>;
import { Variants, VariantsConfig, VariantOptions, Simplify } from "./index.js";
/**
 * Utility type to infer the first argument of a variantProps function.
 */
export type VariantPropsOf<T> = T extends (props: infer P) => any ? P : never;
/**
 * Type for the variantProps() argument – consists of the VariantOptions and an optional className for chaining.
 */
type VariantProps<C extends VariantsConfig<V>, V extends Variants = C["variants"]> = VariantOptions<C> & {
    class?: string;
    className?: string;
};
export declare function variantProps<C extends VariantsConfig<V>, V extends Variants = C["variants"]>(config: Simplify<C>): <P extends VariantProps<C, C["variants"]>>(props: P) => {
    class: string;
} & Omit<P, keyof C["variants"]>;
type VariantsOf<T, V> = T extends VariantsConfig ? V : {};
type AsProps<T extends ElementType = ElementType> = {
    as?: T;
};
type PolymorphicComponentProps<V, T extends ElementType> = AsProps<T> & Omit<ComponentProps<T>, "as" | keyof V> & V;
export declare function styled<T extends ElementType, C extends VariantsConfig<V>, V extends Variants = VariantsOf<C, C["variants"]>>(type: T, config: string | Simplify<C>): <As extends ElementType<any> = T>(props: PolymorphicComponentProps<VariantOptions<C, C["variants"]>, As>) => VNode | null;
/**
 * No-op function to mark template literals as tailwind strings.
 */
export declare const tw: (template: {
    raw: readonly string[] | ArrayLike<string>;
}, ...substitutions: any[]) => string;
export {};
